/* Define hyperelliptic curve y^2=x(x-r1)...
where right side has odd degree.
Range of primes min_p <= p < max_p */
#define r1 (-1)
#define r2 (-2)
#define r3 (-3)
#define r4 (-7)

#define min_p 400001 /*must be odd*/
#define max_p 500000

#define degree 5 /*must be odd */

#define f(x) (issquare1(x,0)*issquare1(x,r1)*issquare1(x,r2)*\
              issquare1(x,r3)*issquare1(x,r4))

