#include <stdio.h>
#include <math.h>
#include <stdlib.h>

#define C 3.248367785
#define scale 100
#define halfscale 50
#define Pi 3.1415926




main()
{ int  i,j, temp1, count=0;
 float graph[scale];
 float theta;
 int p, N1;



for(i=0;i<scale;i++)
      graph[i]=0;
 

 for(;;)
   {  if((j= (scanf("%i", &p) != 1) || ( scanf("%i", &N1) != 1))) 
       break;
   theta = acos((1+p-N1)/(2*sqrt(p)));
   temp1 = floor(scale*(theta)/Pi+0.5)-1;
   graph[temp1] +=1;
   count++;
   }


 printf("[ ");
 for(i=0; i< 99;i++)
   {printf("%f,", graph[i]/count);
   if(((i+1)%5 == 0)) printf("\n");}
 printf(" %f ]\n", graph[99]/count);

 

 exit(0);
}















