#include <stdio.h>
#include <math.h>
#include <stdlib.h>

#define C 3.248367785
#define scale 100
#define halfscale 50
#define Pi 3.1415926



float sin2(float x)
{float si;
 si = sin(x*Pi/99);
 return (2/99.0)*si*si;
}




main()
{ int  i;

 



 printf("[ ");
 for(i=0; i< 99;i++)
   {printf("%f,", sin2(i));
   if(((i+1)%5 == 0)) printf("\n");}
 printf(" %f ]\n", sin2(99));

 

 exit(0);
}















